import request from '@/config/axios'

export interface DaPointVO {
  id: string
  pointNo: string,
  pointName: string,
  pointType: string,
  dataType: string,
  valueType: string,
  storeType: string,
  unit: string,
  unittransfactor: number,
  defaultValue: number,
  maxValue: number,
  minValue: number,
  minfreqid: string,
  remark: string,
  isEnable: number,
}

export interface DaPointPageReqVO extends PageParam {
  pointNo?: string,
  pointName?: string
}

// 查询DaPoint列表
export const getDaPointPage = (params: DaPointPageReqVO) => {
  return request.get({ url: '/data/da/point/page', params })
}

// 查询DaPoint列表
export const getPointList = (params: DaPointPageReqVO) => {
  return request.get({ url: '/data/da/point/list', params })
}

// 查询DaPoint详情
export const getDaPoint = (id: number) => {
  return request.get({ url: `/data/da/point/info/${id}`})
}

// 新增DaPoint
export const createDaPoint = (data: DaPointVO) => {
  return request.post({ url: '/data/da/point/create', data })
}

// 修改DaPoint
export const updateDaPoint = (data: DaPointVO) => {
  return request.put({ url: '/data/da/point/update', data })
}

// 删除DaPoint
export const deleteDaPoint = (id: number) => {
  return request.delete({ url: '/data/da/point/delete?id=' + id })
}

//导出DaPointList
export const exportDaPoint = (params) => {
  return request.download({ url: '/data/da/point/export', params })
}

// 下载用户导入模板
export const importPointTemplate = () => {
  return request.download({ url: '/data/da/point/get-import-template' })
}
